pub fn sum_tensor_dim<T: Field>(
src: &Tensor<T, CpuBackend>,
dim: usize,
) -> Tensor<T, CpuBackend>Expand description
Computes the sum of the tensor along a dimension.
pub fn sum_tensor_dim<T: Field>(
src: &Tensor<T, CpuBackend>,
dim: usize,
) -> Tensor<T, CpuBackend>Computes the sum of the tensor along a dimension.