pub struct Tensor<T, A: Backend = CpuBackend> {
pub storage: Buffer<T, A>,
pub dimensions: Dimensions,
}Fields
storage: Buffer<T, A>dimensions: DimensionsImplementations
Sourceimpl<T, A: Backend> Tensor<T, A>
impl<T, A: Backend> Tensor<T, A>
pub fn with_sizes_in(sizes: impl AsRef<[usize]>, allocator: A) -> Self
pub fn zeros_in(sizes: impl AsRef<[usize]>, allocator: A) -> Self
pub fn zeros_in_with_total_capacity( sizes: impl AsRef<[usize]>, allocator: A, ) -> Self
pub fn try_with_sizes_in( sizes: impl AsRef<[usize]>, allocator: A, ) -> Result<Self, TryReserveError>
pub fn reshape_in_place(&mut self, sizes: impl AsRef<[usize]>)
pub fn reshape(self, sizes: impl AsRef<[usize]>) -> Self
Sourcepub unsafe fn reshape_unchecked(self, dimensions: Dimensions)
pub unsafe fn reshape_unchecked(self, dimensions: Dimensions)
Safety
The caller must ensure that the new dimensions are compatible with the existing dimensions.
pub fn flatten_in_place(&mut self)
pub fn flatten(self) -> Self
pub fn into_buffer(self) -> Buffer<T, A>
pub fn as_buffer(&self) -> &Buffer<T, A>
pub fn as_mut_buffer(&mut self) -> &mut Buffer<T, A>
pub fn backend(&self) -> &A
pub fn shape(&self) -> &Dimensions
pub fn strides(&self) -> &[usize]
pub fn as_ptr(&self) -> *const T
Sourcepub unsafe fn owned_unchecked(&self) -> ManuallyDrop<Self>
pub unsafe fn owned_unchecked(&self) -> ManuallyDrop<Self>
Safety
This function is unsafe because it enables bypassing the lifetime of the tensor.
Sourcepub unsafe fn owned_unchecked_in(
&self,
storage_allocator: A,
) -> ManuallyDrop<Self>
pub unsafe fn owned_unchecked_in( &self, storage_allocator: A, ) -> ManuallyDrop<Self>
Safety
This function is unsafe because it enables bypassing the lifetime of the tensor.
pub fn total_len(&self) -> usize
pub fn as_mut_ptr(&mut self) -> *mut T
pub fn as_view(&self) -> TensorView<'_, T, A>
pub fn as_view_mut(&mut self) -> TensorViewMut<'_, T, A>
pub fn get(&self, index: usize) -> Option<TensorView<'_, T, A>>
pub fn get_mut(&mut self, index: usize) -> Option<TensorViewMut<'_, T, A>>
pub fn split(&self) -> impl Iterator<Item = TensorView<'_, T, A>>
pub fn split_mut(&mut self) -> impl Iterator<Item = TensorViewMut<'_, T, A>>
Sourcepub unsafe fn assume_init(&mut self)
pub unsafe fn assume_init(&mut self)
Safety
pub fn flatten_to_base<F: Field>(self) -> Tensor<F, A>where
T: ExtensionField<F>,
pub fn into_extension<ET: ExtensionField<T>>(self) -> Tensor<ET, A>where
T: Field,
Sourceimpl<T> Tensor<T, CpuBackend>
impl<T> Tensor<T, CpuBackend>
Sourceimpl<T: Field> Tensor<T, CpuBackend>
impl<T: Field> Tensor<T, CpuBackend>
Sourcepub fn sum(&self, dim: usize) -> Tensor<T, CpuBackend>
pub fn sum(&self, dim: usize) -> Tensor<T, CpuBackend>
Computes the sum of the tensor along a dimension.