pub trait TransposeBackend<T>: Backend {
// Required method
fn transpose_tensor_into(
src: &Tensor<T, Self>,
dst: TensorViewMut<'_, T, Self>,
);
}Expand description
A backend that supports the 2D transpose operation.
The operation assumes the input tensor is a 2D tensor with the last two dimensions being the dimensions to be transposed.
Required Methods
Sourcefn transpose_tensor_into(src: &Tensor<T, Self>, dst: TensorViewMut<'_, T, Self>)
fn transpose_tensor_into(src: &Tensor<T, Self>, dst: TensorViewMut<'_, T, Self>)
Transposes the input tensor into the output tensor.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".